# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_streaming_started import CallStreamingStarted

__all__ = ["CallStreamingStartedWebhookEvent"]


class CallStreamingStartedWebhookEvent(BaseModel):
    data: Optional[CallStreamingStarted] = None
