# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .requirement_group import RequirementGroup

__all__ = ["RequirementGroupListResponse"]

RequirementGroupListResponse: TypeAlias = List[RequirementGroup]
