# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["StockExchange"]

StockExchange: TypeAlias = Literal[
    "NONE",
    "NASDAQ",
    "NYSE",
    "AMEX",
    "AMX",
    "ASX",
    "B3",
    "BME",
    "BSE",
    "FRA",
    "ICEX",
    "JPX",
    "JSE",
    "KRX",
    "LON",
    "NSE",
    "OMX",
    "SEHK",
    "SSE",
    "STO",
    "SWX",
    "SZSE",
    "TSX",
    "TWSE",
    "VSE",
]
