# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_siprec_started import CallSiprecStarted

__all__ = ["CallSiprecStartedWebhookEvent"]


class CallSiprecStartedWebhookEvent(BaseModel):
    data: Optional[CallSiprecStarted] = None
