# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict
from typing_extensions import TypeAlias

from .campaign_sharing_status import CampaignSharingStatus

__all__ = ["PartnerCampaignRetrieveSharingStatusResponse"]

PartnerCampaignRetrieveSharingStatusResponse: TypeAlias = Dict[str, CampaignSharingStatus]
