# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["EmbeddingSimilaritySearchParams"]


class EmbeddingSimilaritySearchParams(TypedDict, total=False):
    bucket_name: Required[str]

    query: Required[str]

    num_of_docs: int
